==> SmugMug-3.5.6.0.zip: SmugMug.lrplugin/SmWatermark.lua <==
LuaQ                    a      A@   E     \           ܀   AA  E   \        ܁ 
  EB    $    B$C  \B	ÆFBC U	BJ   AC  bB	BFF	BFF	BF                 	        	          	B                       	       	              	         	   $          require 
       SmAccount        SmAPI        SmConstants 
       SmDialogs        SmLocalization        SmListItem 	       SmLogger        SmTable 
       setmetatable        __call        __index        __tostring 	       BASE_URI        /watermark/        URI        %d        FIELDS        Name 	       Dissolve        Pinned 
       SmallestSize        Uri 	       LOC_ITEM        OBJECT_WATERMARK 
       LOC_ITEMS        OBJECT_WATERMARKS        bind        share        addObserver        build 	       defaults        edit        exists        get 
       getButton 	                      D   F     @  ] ^               new        Watermarks                         "   $                          < SmWatermark namespace >                         ?   k    	      A  ܀   @@   D  F      \ ZA      KA  $                     \A             require        SmStringUtils 	       getPrefs        hasFeature        FEATURE_WATERMARK        addObserver 
       WatermarkUri            N   i    
,     @ @ 	 @D   D    A  AA@      @  AWA A A@	 ABA  A     
       LIST_REFRESH        watermarksRefreshing 	       indirect        get        isEmpty        Watermarks  
       WatermarkUri        message        Invalid Watermark 8       An invalid watermark was set, the value has been reset.                                     o       
F    
  	A@D  F	AJA  IAA  Ł  D FB܁B@Z       @ F  W@C  C@A  AAA F  E Fʂ  CDD\B!    C@A  AAA C@      AA             title 
       No watermark        value        NIL_STRING 
       separator        string        format        Proof (%s)        ATTRIBUTE_DEFAULT                Watermarks        next         table        insert        pairs        Name        Uri        ACTION_REFRESH        ... 
       LIST_REFRESH        watermarks                                    
  E@     @  \	@ 	@AD  F 	@ E@  \ F 	@               Name        LOC        OBJECT_ACTION_NEW 	       LOC_ITEM 	       Dissolve                Pinned        LOCATION_CENTER 
       SmallestSize        require        SmMedia        SIZE_LARGE_SHORT                            p   #    AA   E    \       A܁ W  B   C A  BC d      BB     ƂB   ƂBB       @  I!    C   A  I  @BJ IICDIDC  I
D K\ 	DK   F
A E
DGA  \
  	EĐD  \ 	E"D  ˃JD  I
  E	 E	 \  U
	E	EGD \ 	E˄J  ʅ  	 A
  FJ
  E	 
 \ 	FFJ	FJ  	   IFKI  	  ܆ ƆKʆ  	 A  GLEI   IIEĐbD  ܃D ܄ J   L IIEG  I܄   
  D F	FDFF	FJ   M
IM
I   
ƆF
ʆ   NN
  D F	GDFG	GJ   OIOI   ǇGʇ   PP
  D F	HDFH	HJ   QIQIE Ņ  ܅ EĐD  KD     E ŅEG ܅ K EGRESREħETT A  \E
F 	FĐ	R	FS	UD  \ 	FD  \bC  ܂   E	  VCV \ @E	  VCV \ @  ׭Ƀ׮    D    D \CD  F ÂYU  CC  @  ƃ\  
 	׭	ڮD  F\ Z   AD ZD    A 	DF	DC  [ C      [   @C\    @ C C\   @  C  r          import        LrFunctionContext        require        SmAnalytics        SmMedia 
       osFactory  	       getPrefs        callWithContext        makePropertyTable        Watermarks        pairs 	       defaults        view        spacing        control_spacing        fill       ?       size        small        bind_to_object        assert        row        label_spacing        static_text        title        ATTRIBUTE_NAME        : 
       alignment        right        width        label_width        edit_field        fill_horizontal        value        Name        LOC 2       $$$/SmugMug/Attribute/Size/Smallest=Smallest Size        popup_menu        items '       $$$/SmugMug/Attribute/Size/Thumb=Thumb        SIZE_THUMB_SHORT '       $$$/SmugMug/Attribute/Size/Small=Small        SIZE_SMALL_SHORT )       $$$/SmugMug/Attribute/Size/Medium=Medium        SIZE_MEDIUM_SHORT '       $$$/SmugMug/Attribute/Size/Large=Large        SIZE_LARGE_SHORT )       $$$/SmugMug/Attribute/Size/XLarge=XLarge        SIZE_XLARGE_SHORT 
       SmallestSize        ATTRIBUTE_LOCATION        ATTRIBUTE_LOCATION_BOTTOM        LOCATION_BOTTOM        ATTRIBUTE_LOCATION_BOTTOM_LEFT        LOCATION_BOTTOMLEFT         ATTRIBUTE_LOCATION_BOTTOM_RIGHT        LOCATION_BOTTOMRIGHT        ATTRIBUTE_LOCATION_CENTER        LOCATION_CENTER        ATTRIBUTE_LOCATION_LEFT        LOCATION_LEFT        ATTRIBUTE_LOCATION_RIGHT        LOCATION_RIGHT        ATTRIBUTE_LOCATION_TOP 
       LOCATION_TOP        ATTRIBUTE_LOCATION_TOP_LEFT        LOCATION_TOPLEFT        ATTRIBUTE_LOCATION_TOP_RIGHT        LOCATION_TOPRIGHT        ATTRIBUTE_LOCATION_TILE        LOCATION_TILE        Pinned        ATTRIBUTE_FADE        min                max       Y@
       precision 
       increment        large_increment       $@       width_in_digits       @	       Dissolve        slider 	       integral        OBJECT_ACTION_CREATE 	       LOC_ITEM        OBJECT_ACTION_EDIT 	       category 	       Settings        action        Open        label        Create        Edit 	       property        TYPE_WATERMARK        presentModalDialog 	       contents        save_frame        SmugMugEditWatermark        actionVerb        ACTION_CREATE        ACTION_EDIT        Close        isOK        Save        Cancel        create        get        makeBinding                      D  F     \ H        
       makeBindable                                     t            @     J    I  IA  @A@     ƀA A   @                  get        filter 
       filteruri        errors         Code 
       NOT_FOUND                              e   D  F    A  \ ZA   I@W@  @  D KA \AW@  AJ   B  B BD  F UBC J  CI  IB  W@	 ƁD܁       ܁ A      B @D FE\ 	CFEI!   @ W@ B  @ 
  I I@  I@W@A   @  A @W   C  AA A            hasFeature        FEATURE_WATERMARK        Watermarks         watermarksRefreshing        debug        SmWatermark.get - start        get        string        format        URI        !watermarks 	       nickname        filter        FIELDS 
       filteruri        errors        httpSuccess        Code        getObjectByLocator        ipairs        Uri 	       stripUri        next        build 
       WatermarkUri        SmWatermark.get - end                              !         J    
 A   "B A $   IA         I   I  CA I                push_button        enabled        keys        tokenRefreshing        watermarksRefreshing        object        pluginContext 
       operation        action        width 
       button_width        title 
       LOC_ITEMS        ...                  
     @   @   @ @                  tokenRefreshing        watermarksRefreshing                                      @   @            show                                         

==> SmugMug-3.5.9.1.zip: SmugMug.lrplugin/SmWatermark.lua <==
LuaQ                    a      A@   E     \           ܀   AA  E   \        ܁ 
  EB    $    B$C  \B	ÆFBC U	BJ   AC  bB	BFF	BFF	BF                 	        	          	B                       	       	              	         	   $          require 
       SmAccount        SmAPI        SmConstants 
       SmDialogs        SmLocalization        SmListItem 	       SmLogger        SmTable 
       setmetatable        __call        __index        __tostring 	       BASE_URI        /watermark/        URI        %d        FIELDS        Name 	       Dissolve        Pinned 
       SmallestSize        Uri 	       LOC_ITEM        OBJECT_WATERMARK 
       LOC_ITEMS        OBJECT_WATERMARKS        bind        share        addObserver        build 	       defaults        edit        exists        get 
       getButton 	                      D   F     @  ] ^               new        Watermarks                         "   $                          < SmWatermark namespace >                         ?   k    	      A  ܀   @@   D  F      \ ZA      KA  $                     \A             require        SmStringUtils 	       getPrefs        hasFeature        FEATURE_WATERMARK        addObserver 
       WatermarkUri            N   i    
,     @ @ 	 @D   D    A  AA@      @  AWA A A@	 ABA  A     
       LIST_REFRESH        watermarksRefreshing 	       indirect        get        isEmpty        Watermarks  
       WatermarkUri        message        Invalid Watermark 8       An invalid watermark was set, the value has been reset.                                     o       
F    
  	A@D  F	AJA  IAA  Ł  D FB܁B@Z       @ F  W@C  C@A  AAA F  E Fʂ  CDD\B!    C@A  AAA C@      AA             title 
       No watermark        value        NIL_STRING 
       separator        string        format        Proof (%s)        ATTRIBUTE_DEFAULT                Watermarks        next         table        insert        pairs        Name        Uri        ACTION_REFRESH        ... 
       LIST_REFRESH        watermarks                                    
  E@     @  \	@ 	@AD  F 	@ E@  \ F 	@               Name        LOC        OBJECT_ACTION_NEW 	       LOC_ITEM 	       Dissolve                Pinned        LOCATION_CENTER 
       SmallestSize        require        SmMedia        SIZE_LARGE_SHORT                            p   #    AA   E    \       A܁ W  B   C A  BC d      BB     ƂB   ƂBB       @  I!    C   A  I  @BJ IICDIDC  I
D K\ 	DK   F
A E
DGA  \
  	EĐD  \ 	E"D  ˃JD  I
  E	 E	 \  U
	E	EGD \ 	E˄J  ʅ  	 A
  FJ
  E	 
 \ 	FFJ	FJ  	   IFKI  	  ܆ ƆKʆ  	 A  GLEI   IIEĐbD  ܃D ܄ J   L IIEG  I܄   
  D F	FDFF	FJ   M
IM
I   
ƆF
ʆ   NN
  D F	GDFG	GJ   OIOI   ǇGʇ   PP
  D F	HDFH	HJ   QIQIE Ņ  ܅ EĐD  KD     E ŅEG ܅ K EGRESREħETT A  \E
F 	FĐ	R	FS	UD  \ 	FD  \bC  ܂   E	  VCV \ @E	  VCV \ @  ׭Ƀ׮    D    D \CD  F ÂYU  CC  @  ƃ\  
 	׭	ڮD  F\ Z   AD ZD    A 	DF	DC  [ C      [   @C\    @ C C\   @  C  r          import        LrFunctionContext        require        SmAnalytics        SmMedia 
       osFactory  	       getPrefs        callWithContext        makePropertyTable        Watermarks        pairs 	       defaults        view        spacing        control_spacing        fill       ?       size        small        bind_to_object        assert        row        label_spacing        static_text        title        ATTRIBUTE_NAME        : 
       alignment        right        width        label_width        edit_field        fill_horizontal        value        Name        LOC 2       $$$/SmugMug/Attribute/Size/Smallest=Smallest Size        popup_menu        items '       $$$/SmugMug/Attribute/Size/Thumb=Thumb        SIZE_THUMB_SHORT '       $$$/SmugMug/Attribute/Size/Small=Small        SIZE_SMALL_SHORT )       $$$/SmugMug/Attribute/Size/Medium=Medium        SIZE_MEDIUM_SHORT '       $$$/SmugMug/Attribute/Size/Large=Large        SIZE_LARGE_SHORT )       $$$/SmugMug/Attribute/Size/XLarge=XLarge        SIZE_XLARGE_SHORT 
       SmallestSize        ATTRIBUTE_LOCATION        ATTRIBUTE_LOCATION_BOTTOM        LOCATION_BOTTOM        ATTRIBUTE_LOCATION_BOTTOM_LEFT        LOCATION_BOTTOMLEFT         ATTRIBUTE_LOCATION_BOTTOM_RIGHT        LOCATION_BOTTOMRIGHT        ATTRIBUTE_LOCATION_CENTER        LOCATION_CENTER        ATTRIBUTE_LOCATION_LEFT        LOCATION_LEFT        ATTRIBUTE_LOCATION_RIGHT        LOCATION_RIGHT        ATTRIBUTE_LOCATION_TOP 
       LOCATION_TOP        ATTRIBUTE_LOCATION_TOP_LEFT        LOCATION_TOPLEFT        ATTRIBUTE_LOCATION_TOP_RIGHT        LOCATION_TOPRIGHT        ATTRIBUTE_LOCATION_TILE        LOCATION_TILE        Pinned        ATTRIBUTE_FADE        min                max       Y@
       precision 
       increment        large_increment       $@       width_in_digits       @	       Dissolve        slider 	       integral        OBJECT_ACTION_CREATE 	       LOC_ITEM        OBJECT_ACTION_EDIT 	       category 	       Settings        action        Open        label        Create        Edit 	       property        TYPE_WATERMARK        presentModalDialog 	       contents        save_frame        SmugMugEditWatermark        actionVerb        ACTION_CREATE        ACTION_EDIT        Close        isOK        Save        Cancel        create        get        makeBinding                      D  F     \ H        
       makeBindable                                     t            @     J    I  IA  @A@     ƀA A   @                  get        filter 
       filteruri        errors         Code 
       NOT_FOUND                              e   D  F    A  \ ZA   I@W@  @  D KA \AW@  AJ   B  B BD  F UBC J  CI  IB  W@	 ƁD܁       ܁ A      B @D FE\ 	CFEI!   @ W@ B  @ 
  I I@  I@W@A   @  A @W   C  AA A            hasFeature        FEATURE_WATERMARK        Watermarks         watermarksRefreshing        trace        SmWatermark.get - start        get        string        format        URI        !watermarks 	       nickname        filter        FIELDS 
       filteruri        errors        httpSuccess        Code        getObjectByLocator        ipairs        Uri 	       stripUri        next        build 
       WatermarkUri        SmWatermark.get - end                              !         J    
 A   "B A $   IA         I   I  CA I                push_button        enabled        keys        tokenRefreshing        watermarksRefreshing        object        pluginContext 
       operation        action        width 
       button_width        title 
       LOC_ITEMS        ...                  
     @   @   @ @                  tokenRefreshing        watermarksRefreshing                                      @   @            show                                         
